@@ -2,12 +2,20 @@ class Law < ActiveRecord::Base
 
   acts_as_paranoid
 
+  TEXT_MAXLENGTH = 200
+
+  RENDER_TYPE_TEXT = 0
+  RENDER_TYPE_HTML = 1
+
   belongs_to :prefecture
 
   validates_presence_of :company,:manager,:zipcode01, :zipcode02,
                       :prefecture_id,:address_city,:address_detail,
                       :tel01,:tel02,:tel03,:email,:url,
-                      :necessary_charge,:order_method,:payment_method,:payment_time_limit,:delivery_time,:return_exchange
+                      :necessary_charge,:order_method,:payment_method,:payment_time_limit,:delivery_time,:return_exchange,
+                      :necessary_charge_mobile,:order_method_mobile,:payment_method_mobile,:payment_time_limit_mobile,:delivery_time_mobile,:return_exchange_mobile,
+                      :retailer_id,:render_type
+                      
 
   validates_length_of :company,:manager,:address_city,:address_detail,:email,:url, :maximum => 50
 
@@ -20,13 +28,16 @@ class Law < ActiveRecord::Base
 
   validates_inclusion_of :prefecture_id, :in => 1..47,:message => "を選択してください"
 
-  validates_length_of :necessary_charge,:order_method,:payment_method,:payment_time_limit,:delivery_time,:return_exchange , :maximum => 200
+  validates_length_of :necessary_charge,:order_method,:payment_method,:payment_time_limit,:delivery_time,:return_exchange, :maximum => TEXT_MAXLENGTH
+  validates_length_of :necessary_charge_mobile,:order_method_mobile,:payment_method_mobile,:payment_time_limit_mobile,:delivery_time_mobile,:return_exchange_mobile, :maximum => TEXT_MAXLENGTH
 
   validates_format_of :url, :with=>%r{^(https?://.*|)$}, :message=>"が不正です"
 
-  def validate_on_create
-    errors.add "","複数のデータは登録できません。"  if Law.count > 0
-  end
+  validates_inclusion_of :render_type, :in => 0..1, :message => "を選択してください"
+
+#  def validate_on_create
+#    errors.add "","複数のデータは登録できません。"  if Law.count > 0
+#  end
 
   # 表示系のメソッド
   def zipcode
@@ -44,4 +55,9 @@ class Law < ActiveRecord::Base
   def fax 
     "#{fax01}-#{fax02}-#{fax03}"
   end
+
+  def html?
+    return render_type == RENDER_TYPE_HTML
+  end
+
 end
